*************
rail_plot CLI
*************

.. click:: rail.cli.rail_plot:plot_cli
   :prog: rail-plot
   :nested: none

	    
=======================================
Inspecting plotting configuration files
=======================================

.. click:: rail.cli.rail_plot:inspect_command
   :prog: rail-plot run
   :nested: full

	    
======================================	    
Extracting datasets from a RailProject
======================================

.. click:: rail.cli.rail_plot:extract_datasets_command
   :prog: rail-plot extract-datasets
   :nested: full

	    
=======================================
Combining plots with available datasets
=======================================

.. click:: rail.cli.rail_plot:make_plot_groups
   :prog: rail-plot make-plot-groups
   :nested: full

	    
============
Making plots
============

.. click:: rail.cli.rail_plot:run_command
   :prog: rail-plot run
   :nested: full
